@@ -3,6 +3,8 @@ Generate Audio
 """
 from contextlib import suppress
 
+from hum.gen.util import DFLT_N_SAMPLES, DFLT_SR
+
 with suppress(ModuleNotFoundError, ImportError):
     from hum.gen.diagnosis_sounds import (
         WfGen,
@@ -15,7 +17,11 @@ with suppress(ModuleNotFoundError, ImportError):
     )
 
 with suppress(ModuleNotFoundError, ImportError):
-    from hum.gen.sine_mix import mk_sine_wf, freq_based_stationary_wf
+    from hum.gen.sine_mix import (
+        mk_sine_wf,
+        freq_based_stationary_wf,
+        NumAnnotsAndWaveformChunks,
+    )
 
 with suppress(ModuleNotFoundError, ImportError):
     from hum.gen.voiced_time import Voicer, tell_time_continuously
